# -*- coding: utf-8 -*-
# pylint: disable=missing-docstring
import sys

from foran.cli import app

if __name__ == '__main__':
    sys.exit(app(prog_name='foran'))  # pragma: no cover
